<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Loopback</name>
    <message>
        <location filename="loopback.cpp" line="133"/>
        <source>This plugin provides DMX loopback. Data written to each output is forwarded to the respective input.</source>
        <translation>Dieses Plugin bietet eine DMX-Rückschleife. Daten, die auf die Ausgänge geschrieben werden, werden an die Eingänge weitergeleitet.</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="146"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="149"/>
        <location filename="loopback.cpp" line="171"/>
        <source>Status: Used</source>
        <translation>Status: In Benutzung</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="152"/>
        <location filename="loopback.cpp" line="174"/>
        <source>Status: Not used</source>
        <translation>Status: Nicht benutzt</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="168"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
</context>
</TS>
